function FilterAssistant() {
	/* this is the creator function for your scene assistant object. It will be passed all the 
	   additional parameters (after the scene name) that were passed to pushScene. The reference
	   to the scene controller (this.controller) has not be established yet, so any initialization
	   that needs the scene controller should be done in the setup function below. */
}

FilterAssistant.prototype.setup = function()
{
    for (var i = 0; i < ThisApp.preferences.filters.length; i++)
        ThisApp.preferences.filters[i].index = i;
    
    this.controller.setupWidget("filterSwitchWgt",
        this.attributes =
            {trueValue: true,
             falseValue: false},
        this.filterSwitchModel =
            {value: ThisApp.filterSwitch,
             disabled: false}
        );
    
    // combine field
    this.controller.setupWidget
	("combineWgt",
	 {label: "Combine",
	  choices:
	    [{label: "and", value: 0},
             {label: "or", value: 1}]},
	 this.combineModel = {value: ThisApp.preferences.filterCombine}
	);
        
    // filter list
    this.listAttributes =
	{
	    itemTemplate: "filter/filterRowTemplate",
	    listTemplate: "filter/filterListTemplate",
	    swipeToDelete: true,
	    renderLimit: 40,
	    reorderable: true,
            dividerFunction: this.filterDivider.bind(this),
            addItemLabel: "Add filter"
	};
    this.controller.setupWidget
	("filterListWgt",
	 this.listAttributes,
	 this.listModel = {items: ThisApp.preferences.filters}
	);
        
    // filter list widgets
    // --> field
    this.filterFieldAttr =
        {label: "Field",
         choices:
            [{label: "Title", value: 0},
             {label: "Format seen", value: 1},
             {label: "Year seen", value: 2},
             {label: "Date seen", value: 3},
             {label: "Number of times seen", value: 4},
             {label: "Rating", value: 5},
             {label: "Format owned", value: 6},
             {label: "Location", value: 7},
             {label: "Director", value: 8},
             {label: "Cast", value: 9},
             {label: "Genre", value: 10},
             {label: "Notes", value: 11}],
         modelProperty: 'field'};
    this.controller.setupWidget("filterFieldWgt", this.filterFieldAttr);
    // --> equals
    this.filterEqualsAttr =
        {label: "Method",
         choices:
            [{label: "is", value: 0},
             {label: "is not", value: 1},
             {label: "contains", value: 2},
             {label: "doesn't contain", value: 3},
             {label: "is smaller than", value: 4},
             {label: "is greater than", value: 5}],
         modelProperty: 'equals'};
    this.controller.setupWidget("filterEqualsWgt", this.filterEqualsAttr);
    // --> text: string
    this.filterTextAttr =
        {hintText: "filter text",
	 autoReplace: false,
	 textCase: Mojo.Widget.steModeLowerCase,
	 enterSubmits: false,
	 autoFocus: false,
         modelProperty: 'text'};
   this.controller.setupWidget("filterTextWgt", this.filterTextAttr);
   
   // list events
   // --> add
   this.filterListAddHandler = this.filterListAdd.bindAsEventListener(this);
   this.controller.listen("filterListWgt", Mojo.Event.listAdd, this.filterListAddHandler);
   // --> delete
   this.filterListDeleteHandler = this.filterListDelete.bindAsEventListener(this);
   this.controller.listen("filterListWgt", Mojo.Event.listDelete, this.filterListDeleteHandler);
   // --> reorder
   this.filterListReorderHandler = this.filterListReorder.bindAsEventListener(this);
   this.controller.listen("filterListWgt", Mojo.Event.listReorder, this.filterListReorderHandler);
   // --> change
   this.filterListChangeHandler = this.filterListChange.bindAsEventListener(this);
   this.controller.listen("filterListWgt", Mojo.Event.listChange, this.filterListChangeHandler);
    
    // some object variables to be used later on
    this.filterListWidget = this.controller.get("filterListWgt");    
}

FilterAssistant.prototype.activate = function(event)
{
}

FilterAssistant.prototype.deactivate = function(event)
{
    Mojo.log("filter scene deactivate");
    ThisApp.filterSwitch = this.filterSwitchModel.value;
    ThisApp.preferences.filterCombine = this.combineModel.value;
    for (var i = 0; i < ThisApp.preferences.filters.length; i++)
    {
	ThisApp.preferences.filters[i].field = this.listModel.items[i].field;
	ThisApp.preferences.filters[i].equals = this.listModel.items[i].equals;
	ThisApp.preferences.filters[i].text = this.listModel.items[i].text;
    }
    ThisApp.filterChanged = true; // just assume it's been changed in some way
    
    ThisApp.preferences.saveFilterList();
}

FilterAssistant.prototype.cleanup = function(event)
{
    this.controller.stopListening("filterListWgt", Mojo.Event.listAdd, this.filterListAddHandler);
    this.controller.stopListening("filterListWgt", Mojo.Event.listDelete, this.filterListDeleteHandler);    
    this.controller.stopListening("filterListWgt", Mojo.Event.listReorder, this.filterListReorderHandler);
    this.controller.stopListening("filterListWgt", Mojo.Event.listChange, this.filterListChangeHandler); 
}

FilterAssistant.prototype.filterListAdd = function(event)
{
    var newItem = {index: ThisApp.preferences.filters.length, field: 0, equals: 0, text: ""};
    ThisApp.preferences.filters.push(newItem);
    this.listModel.items = ThisApp.preferences.filters;
    this.filterListWidget.mojo.noticeAddedItems(this.listModel.items.length, [newItem]);
    ThisApp.filterChanged = true;
}

FilterAssistant.prototype.filterListDelete = function(event)
{
    var deleteIndex = ThisApp.preferences.filters.indexOf(event.item);
    ThisApp.preferences.filters.splice(deleteIndex, 1);
    for (var i = 0; i < ThisApp.preferences.filters.length; i++)
        ThisApp.preferences.filters[i].index = i;    
    this.filterListWidget.mojo.noticeRemovedItems(this.listModel.items.length, []);
    ThisApp.filterChanged = true;
}

FilterAssistant.prototype.filterListReorder = function(event)
{
    var fromIndex = ThisApp.preferences.filters.indexOf(event.item);
    var toIndex = event.toIndex;
    ThisApp.preferences.filters.splice(fromIndex, 1);
    ThisApp.preferences.filters.splice(toIndex, 0, event.item);
    for (var i = 0; i < ThisApp.preferences.filters.length; i++)
        ThisApp.preferences.filters[i].index = i;    
    this.listModel.items = ThisApp.preferences.filters;
    this.filterListWidget.mojo.noticeUpdatedItems(this.listModel.items.length, []);        
    ThisApp.filterChanged = true;
}

FilterAssistant.prototype.filterListChange = function(event)
{
    ThisApp.filterChanged = true;
}

FilterAssistant.prototype.filterDivider = function(itemModel)
{
    return itemModel.index+1;
};