function ShowMovieAssistant(movieList, movieIndex)
{
    this.movieList = movieList;
    this.movieIndex = movieIndex;
    
    this.movie = this.movieList[this.movieIndex];

    // compatibility with version 1.0.3 and earlier: these fields were added so will be undefined    
    if (this.movie.director == undefined)	this.movie.director = "";
    if (this.movie.cast == undefined)		this.movie.cast = "";
    if (this.movie.genre == undefined)		this.movie.genre = "";
    if (this.movie.owned == undefined)		this.movie.owned = 0;
    if (this.movie.location == undefined)	this.movie.location = "";
}

ShowMovieAssistant.prototype.setup = function()
{
    this.updateVisuals();
    
    // setup application menu
    this.controller.setupWidget(Mojo.Menu.appMenu, ThisApp.AppMenuAttributes, ThisApp.AppMenuModel);    
    
    // define next/prev command menu
    this.nextPrevMenuModel =
	{
	    items:
		[{label: "Edit", command: "do-Edit"},
		 {items:[]},
		 {items:[]}]
	};
    // show buttons as necessary
    this.nextPrevMenuModel.items[1].items.push({});    // center prev/next buttons
    if (this.movieIndex > 0)
	this.nextPrevMenuModel.items[1].items.push({icon: "back", command:"do-viewPrevious"});
    else
	this.nextPrevMenuModel.items[1].items.push({icon: "", command: "", label: ""});
    if (this.movieIndex < this.movieList.length-1)
	this.nextPrevMenuModel.items[1].items.push({icon: "forward", command:"do-viewNext"});
    else
	this.nextPrevMenuModel.items[1].items.push({icon: "", command: "", label: ""});

    this.nextPrevMenuModel.items[2].items.push({});	// center prev/next buttons
    this.nextPrevMenuModel.items[2].items.push({iconPath: "images/url-icon.png", command: "do-Web"});

    // add command menu
    this.controller.setupWidget(Mojo.Menu.commandMenu, undefined, this.nextPrevMenuModel); 
}

ShowMovieAssistant.prototype.activate = function(event)
{
    this.updateVisuals();
}


ShowMovieAssistant.prototype.deactivate = function(event)
{
}

ShowMovieAssistant.prototype.cleanup = function(event)
{
	/* this function should do any cleanup needed before the scene is destroyed as 
	   a result of being popped off the scene stack */
}

ShowMovieAssistant.prototype.handleCommand = function(event)
{
    if (event.type == Mojo.Event.command)
    {
	switch(event.command)
	{
	    case "do-Edit":
		Mojo.Controller.stageController.pushScene("edit-movie", this.movieList, this.movieIndex);
		break;
	    case "do-viewPrevious":
		Mojo.Controller.stageController.swapScene
			({transition: Mojo.Transition.crossFade, name: "show-movie"},
			 this.movieList,
			 this.movieIndex-1);
		break;
	    case "do-viewNext":
		Mojo.Controller.stageController.swapScene
			({transition: Mojo.Transition.crossFade, name: "show-movie"},
			 this.movieList,
			 this.movieIndex+1);
		break;
	    case "do-Web":
		var link = "http://imdb.com/find?" + this.movie.title; 
		this.controller.serviceRequest("palm://com.palm.applicationManager",
		    {method: "open",
		     parameters:
			{id: "com.palm.app.browser",
			 params: {target: link}}});		
		break;
	}
    }
    
    if (event.type == Mojo.Event.commandEnable)
    {
        if (event.command == ThisApp.MenuFilterCommand)
            event.preventDefault();
    }    
}

ShowMovieAssistant.prototype.updateVisuals = function()
{    
    // title
    this.controller.get("movieTitle").innerHTML = this.movie.title;
    
    // properties
    // --> where
    var s = "";
    if (this.movie.where == 0)		s = "Cinema";
    else if (this.movie.where == 1)	s = "TV";
    else if (this.movie.where == 2)	s = "DVD";
    else if (this.movie.where == 3)	s = "Blu-Ray";
    else if (this.movie.where == 4)	s = "VHS";
    else if (this.movie.where == 5)	s = "Video file";
    else if (this.movie.where == 6)	s = "YouTube";
    else if (this.movie.where == 7)	s = "Netflix";
    else if (this.movie.where == 8)	s = "Online";
    else if (this.movie.where == 9)	s = "Other";
    //var s = Mojo.Format.formatChoice(this.movie.where, "0#Cinema|1#TV|2#DVD|3#Blu-Ray|4#VHS");
    this.controller.get("movieWhere").innerHTML = s;
    // --> when
    var date1 = new Date();
    date1.setTime(this.movie.date);
    this.date2 = Mojo.Format.formatDate(date1, {date: 'long'});
    this.controller.get("movieWhen").update(this.date2);
    // --> count
    if (this.movie.viewCount == 0)
	this.controller.get("movieViewCount").innerHTML = "not seen (yet)";
    else
	this.controller.get("movieViewCount").innerHTML = this.movie.viewCount;
    // --> rating
    s = "";
    for (var i = 0; i < 5; i++)
    {
	if (i < this.movie.rating)
	    s = s + '<img src="images/star_yellow.png"></img>';
	else
	    s = s + '<img src="images/star_empty.png"></img>';
    }
    this.controller.get("movieRating").innerHTML = s;
    
    // --> owned
    var s = "";
    if (this.movie.owned == 0)		s = "Don't own it";
    else if (this.movie.owned == 1)	s = "DVD";
    else if (this.movie.owned == 2)	s = "Blu-Ray";
    else if (this.movie.owned == 3)	s = "VHS";
    else if (this.movie.owned == 4)	s = "Video file";
    //var s = Mojo.Format.formatChoice(this.movie.owned, "0#Don't own it|1#DVD|2#Blu-Ray|3#VHS|4#Video file");
    this.controller.get("movieOwned").innerHTML = s;
    // --> location
    this.controller.get("movieLocation").innerHTML = this.movie.location;
    
    // --> director
    this.controller.get("movieDirector").innerHTML = this.movie.director;
    // --> cast
    this.controller.get("movieCast").innerHTML = this.movie.cast;
    // --> genre
    this.controller.get("movieGenre").innerHTML = this.movie.genre;
    
    // --> separator
    var notesSeparatorElement = this.controller.get("notesSeparator");
    if (this.movie.notes == "")
        notesSeparatorElement.innerHTML = "";
    else
        notesSeparatorElement.innerHTML = "<HR>";

    // notes
    this.controller.get("movieNotes").innerHTML = this.movie.notes;
}