/***************************************
 *  Preferences
 *
 *  filter fields:
 *  - field  = 0:title, 1:format, 2:year, 3:date, 4:count, 5:rating, 6:owned format, 7:location, 8:director, 9:cast, 10:genre, 11:notes 
 *  - equals = 0:is, 1:is not, 2:contains, 3:doesn't contain, 4:less than, 5:more than
 *  - text  = string
****************************************/

var Preferences = Class.create
({
    initialize: function()
    {
        this.cookieVersion = 1;
        
        this.randomOwnedOnly = true;
        this.randomIgnoreLast = 5;
        this.randomLastSelected = [];
        
        this.filterCombine = 0;
        this.filters = [];
    },
    
    loadFromCookie: function()
    {
        // Update globals with preferences or create it.
        this.cookieData = new Mojo.Model.Cookie("comAxiMovieDiaryPrefs");
        var data = this.cookieData.get();
        if (data)
        {
            if (data.cookieVersion == this.cookieVersion)
            {
                // random - owned only
                this.randomOwnedOnly = data.randomOwnedOnly;
                //        - ignore last x items
                if (data.randomIgnoreLast != undefined)
                    this.randomIgnoreLast = data.randomIgnoreLast;
                //        - last selected array
                this.randomLastSelected = [];
                if (data.randomLastSelected != undefined)
                    this.randomLastSelected = data.randomLastSelected.split('~');
                //        - filter combination method (and/or)
                this.filterCombine = 0;
                if (data.filterCombine != undefined)
                    this.filterCombine = data.filterCombine;
            }
            else
            {
                // migrate old preferences here
            }               
        }
    },
    
    saveToCookie: function()
    {
        lastsel = this.randomLastSelected.join('~');
        
        //  store - function to update stored cookie with global values
        this.cookieData.put(
            {cookieVersion: this.cookieVersion,
             randomOwnedOnly: this.randomOwnedOnly,
             randomIgnoreLast: this.randomIgnoreLast,
             randomLastSelected: lastsel,
             filterCombine: this.filterCombine});
    },
    
    loadFilterList: function()
    {
        // load filter list from depot
        this.filterdb = new Mojo.Depot
            ({name: "ext:Filters", version: 1, estimatedSize: 100000, replace: false},
             this.loadFilterDbOpenOk.bind(this),
             this.loadFilterDbOpenFail.bind(this)
            );
    },
    
    loadFilterDbOpenOk: function()
    {
        Mojo.log("loadFilterDbOpenOk");
        this.filterdb.get("filters", this.loadFilterGetSuccess.bind(this), this.loadFilterGetFailed.bind(this));
    },
    
    loadFilterDbOpenFail: function(result)
    {
        Mojo.Log.warn("Can't open ext movie database");
    },
    
    loadFilterGetSuccess: function(fl)
    {
        Mojo.log("loadFilterGetSuccess");
        if (fl == null)
            Mojo.Log.warn("  - filter: loaded_list was null.");
        else
        {
            Mojo.Log.info("  - filter: list was loaded succesfully.");
            this.filters = fl;
            
            ThisApp.filtersChanged = true;
            Mojo.Controller.getAppController().sendToNotificationChain({id: "filtersChanged"});
        }
    },
    
    loadFilterGetFailed: function()
    {
        Mojo.Log.warn("failed to load item from db.");
    },
    
    saveFilterList: function()
    {
        // store filter list in depot
        Mojo.log("saveFilterList called");
        this.filterdb.add("filters", this.filters, this.saveFilterOk.bind(this), this.saveFilterFail.bind(this));
    },    
    
    saveFilterOk: function()
    {
        Mojo.log("filter list saved");
    },
    
    saveFilterFail: function(result)
    {
        Mojo.log("filter list NOT saved");
    },
});